from collections import defaultdict
from datetime import datetime

from edos.ccsds import GROUP_FIRST

from edosl0util.stream import PacketStream


MAX_SEQ_ID = 2**14


def dump(filepath, handler=None):
    """
    Dump PDS file statistics. The entire file will be iterated, which for larger
    PDS files may take a while.
    """
    first_pkt = datetime(3000, 1, 1)
    last_pkt = datetime(1900, 1, 1)
    packets = 0
    groups = 0
    # sequence nums are per APID
    apids = defaultdict(lambda: {'count': 0, 'prev_seq': 0, 'missing': 0})
    for pkt in PacketStream(open(filepath)):
        packets += 1
        h1 = pkt._primary_header
        if h1.sequence_grouping == GROUP_FIRST:
            groups += 1
        apids[h1.apid]['count'] += 1

        seq = h1.source_sequence_count
        apids[h1.apid]['prev_seq'] = seq

        if pkt.stamp:
            first_pkt = min(pkt.stamp, first_pkt)
            last_pkt = max(pkt.stamp, last_pkt)

        try:
            handler and handler(pkt)
        except Exception:
            pass

    return dict(
        first_pkt=first_pkt,
        last_pkt=last_pkt,
        packet_count=packets,
        group_count=groups,
        apids=apids
    )